import { Box, Button, useTheme } from "@mui/material";
import { convertFileSrc } from "@tauri-apps/api/tauri";
import { useEffect, useState } from "react";
import { useSettings } from "../../contexts/SettingsContext";
import { FooterBar } from "../FooterBar/FooterBar";
import { HeaderBar } from "../HeaderBar/HeaderBar";

export const Layout = () => {
  // contexts
  const { settings } = useSettings();
  const theme = useTheme();

  const [imageUrl, setImageUrl] = useState<string | null>(null);

  const setBackground = async (filePath: string) => {
    const assetUrl = convertFileSrc(filePath);
    setImageUrl(assetUrl);
  };

  useEffect(() => {
    setBackground(settings.background.background_image_path);
  }, [settings.background.background_image_path]);

  return (
    <Box
      sx={{
        backgroundColor: theme.palette.background.default,
        backgroundImage: settings.background.background_image_path ? `url(${imageUrl})` : "",
        backgroundSize: "cover",
        backgroundPosition: "center",
        backgroundRepeat: "no-repeat",
        display: "flex",
        flexDirection: "column",
        height: "100vh",
      }}
    >
      <HeaderBar />
      <Box
        sx={{
          display: "flex",
          flexGrow: 1,
          overflow: "auto",
          p: 1,
        }}
      ></Box>
      <FooterBar />
    </Box>
  );
};
