import { Box, TextField } from "@mui/material";
import { useAtom } from "jotai";
import { FC } from "react";
import { defaultSettings } from "../../../../lib/settings";
import { stagedSettingsAtom } from "../../../../lib/store/jotai/settings";
import { CategoryTitle } from "../CategoryTitle";
import { SettingsItem } from "../SettingsItem";

interface ColorsProps {
  sx?: any;
}

export const Colors: FC<ColorsProps> = ({ sx }) => {
  // atoms
  const [stagedSettings, setStagedSettings] = useAtom(stagedSettingsAtom);

  // states
  const handleSettingsColorsValueChange = (settingKey: string, settingValue: boolean | number | string | number[]) => {
    const newSettings = {
      ...stagedSettings,
      colors: {
        ...stagedSettings.colors,
        [settingKey]: settingValue,
      },
    };
    setStagedSettings(newSettings);

    return newSettings;
  };

  return (
    <Box sx={{ sx }}>
      <CategoryTitle title="Colors" />
      <SettingsItem
        defaultText={defaultSettings.colors.accent_color}
        description="Accent color"
        input={
          <TextField
            name="accent_color"
            onChange={(e) => {
              handleSettingsColorsValueChange(e.target.name, e.target.value);
            }}
            sx={{
              width: "100%",
            }}
            size="small"
            type="color"
            value={stagedSettings.colors.accent_color}
            variant="standard"
          />
        }
      />
      <SettingsItem
        defaultText={defaultSettings.colors.background_color}
        description="Background color"
        input={
          <TextField
            name="background_color"
            onChange={(e) => {
              handleSettingsColorsValueChange(e.target.name, e.target.value);
            }}
            sx={{
              width: "100%",
            }}
            size="small"
            type="color"
            value={stagedSettings.colors.background_color}
            variant="standard"
          />
        }
      />
      <SettingsItem
        defaultText={defaultSettings.colors.background_color_popup}
        description="Popup background color"
        input={
          <TextField
            name="background_color_popup"
            onChange={(e) => {
              handleSettingsColorsValueChange(e.target.name, e.target.value);
            }}
            sx={{
              width: "100%",
            }}
            size="small"
            type="color"
            value={stagedSettings.colors.background_color_popup}
            variant="standard"
          />
        }
      />
      <SettingsItem
        defaultText={defaultSettings.colors.footer_color}
        description="Footer color"
        input={
          <TextField
            name="footer_color"
            onChange={(e) => {
              handleSettingsColorsValueChange(e.target.name, e.target.value);
            }}
            sx={{
              width: "100%",
            }}
            size="small"
            type="color"
            value={stagedSettings.colors.footer_color}
            variant="standard"
          />
        }
      />
    </Box>
  );
};
